==> duiba-rcmd-alg-1.0.2-20180319.065442-2-sources.jar: com/duiba/rcmd/material/MaterialInfoTest.java <==
package com.duiba.rcmd.material;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.util.Random;

/**
 * Created by Administrator on 2017/11/14.
 */
public class MaterialInfoTest  {



    public static void main(String[] args) {

        BayesianMaterial  banditActivity = new BayesianMaterial();

        //初始化两个活动
        Random random1 = new Random();


        Materialnfo materialnfo1 = new Materialnfo();

        //ArrayList<Long> clkList = new ArrayList<>();
        //ArrayList<Long> expList = new ArrayList<>();

        List<Map<Long, Long>> hour_clicks = new ArrayList<Map<Long, Long>>(); //每个小时的统计点击
        List<Map<Long, Long>> hour_exposures = new ArrayList<Map<Long, Long>>();//每个小时的统计曝光

        List<Long> click1 = new ArrayList<Long>();;//最近一个小时的点击，每分钟 
        List<Long> click2= new ArrayList<Long>();;//最近一个小时的点击，每分钟 
        List<Long> exposure1= new ArrayList<Long>();;//最近一个小时的点击，每分钟 
        List<Long> exposure2= new ArrayList<Long>();;//最近一个小时的点击，每分钟 
        for(int i = 0;i<10;++i) {

            click1.add(1l);
            click2.add(null);
//
//            click1.add(null);
//            click2.add(20l);
            System.out.println("random1.nextLong()="+click1.get(i));
            System.out.println("random2.nextLong()="+click2.get(i));
            exposure1.add(50l);
            exposure2.add(null);
//
//
//            exposure1.add(null);
//            exposure2.add(50l);
        }

        materialnfo1.materialId = 1l;
        materialnfo1.appId = 9l;
        materialnfo1.click=click1; //最近10分钟点击
        materialnfo1.exposure=exposure1; //最近10分钟曝光
        materialnfo1.setCount(0);
        materialnfo1.setHisClick(0);
        materialnfo1.setHisExposures(0);
        materialnfo1.setReword(0.0);

        Materialnfo materialnfo2 = new Materialnfo();;

        //ArrayList<Long> clkList2 = new ArrayList<>();
        // clkList2.add(0,10l);
        //ArrayList<Long> expList2 = new ArrayList<>();

        materialnfo2.materialId = 2l;
        materialnfo2.appId = 9l;
        materialnfo2.click=click2; //最近10分钟点击
        materialnfo2.exposure=exposure2; //最近10分钟曝光
        materialnfo2.setCount(0);
        materialnfo2.setHisClick(0);
        materialnfo2.setHisExposures(0);
        materialnfo2.setReword(0.0);
        ArrayList<Materialnfo> activityList = new ArrayList<>();
        activityList.add(materialnfo1);
        activityList.add(materialnfo2);


        int cnt1 = 0,cnt2 = 0;
        //System.out.println("activityId\talpha\tm.beta\tm.reward\tm.hctr");

        for(int i = 0;i<10000;i++)
        {

            System.out.println("循环次数"+i);
            System.out.println("0LastClick= " +activityList.get(0).getHisClick());
            System.out.println("0getLastExposure= " +activityList.get(0).getHisExposures());
            System.out.println("0getReward= " +activityList.get(0).getReward());

            System.out.println("0getcounts= " +activityList.get(0).getCount());


            //处理过程中没有改变活动的 expList2 和 clkList2 ，所以每次点击和曝光列表的内容一样，但是改变了 LastClick，LastExposure，Reward，所以每次新循环，这几个指标都不一样了。

            Materialnfo materialnfo = banditActivity.selectActivity(activityList);
            //System.out.println("win_activity_id= " +activity.activityId);
            if(materialnfo.materialId == 2l)
            {

                activityList.set(1,materialnfo);  //不理解

                cnt2++;
//                System.out.println("activityList"+ activityList.get(0).getActivityId() +activityList.get(1).getActivityId());
            }
            else
            {
                activityList.set(0,materialnfo);
                cnt1++;
                //System.out.println("activityList"+ activityList.get(0).getActivityId() +activityList.get(1).getActivityId());
            }
            // System.out.println(m.materialId+"\t"+m.alpha+"\t"+m.beta+"\t"+m.reward/m.count+"\t"+m.lastClick+"\t"+m.lastExposure);
        }
        System.out.println("cnt1 = "+cnt1+" cnt2="+cnt2);
        //System.out.println("activityList"+ activityList.get(0).getActivityId() +activityList.get(1).getActivityId());


    }



}
/**
 0alphas= 11.00000000000001
 0betas= 9.999999999999979
 1alphas= 1.0999999999999999
 1betas= 19.899999999999988
 cnt1 = 9999 cnt2=1
 click1.add(20l);
 click2.add(null);



 1alphas= 5.000000000000633
 1betas= 15.999999999999357
 0alphas= 1.0999999999999999
 0betas= 19.899999999999988
 cnt1 = 292 cnt2=9708

 click1.add(null);
 click2.add(20l);
 **/

==> duiba-rcmd-alg-1.0.3-20180321.095921-1-sources.jar: com/duiba/rcmd/material/MaterialInfoTest.java <==
package com.duiba.rcmd.material;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.util.Random;

/**
 * Created by Administrator on 2017/11/14.
 */
public class MaterialInfoTest  {



    public static void main(String[] args) {

        BayesianMaterial  banditActivity = new BayesianMaterial();

        //初始化两个活动
        Random random1 = new Random();


        Materialnfo materialnfo1 = new Materialnfo();

        //ArrayList<Long> clkList = new ArrayList<>();
        //ArrayList<Long> expList = new ArrayList<>();

        List<Map<Long, Long>> hour_clicks = new ArrayList<Map<Long, Long>>(); //每个小时的统计点击
        List<Map<Long, Long>> hour_exposures = new ArrayList<Map<Long, Long>>();//每个小时的统计曝光

        List<Long> click1 = new ArrayList<Long>();;//最近一个小时的点击，每分钟 
        List<Long> click2= new ArrayList<Long>();;//最近一个小时的点击，每分钟 
        List<Long> exposure1= new ArrayList<Long>();;//最近一个小时的点击，每分钟 
        List<Long> exposure2= new ArrayList<Long>();;//最近一个小时的点击，每分钟 
        for(int i = 0;i<10;++i) {

            click1.add(10l);
            click2.add(null);
//
//            click1.add(null);
//            click2.add(20l);
            System.out.println("random1.nextLong()="+click1.get(i));
            System.out.println("random2.nextLong()="+click2.get(i));
            exposure1.add(50l);
            exposure2.add(null);
//
//
//            exposure1.add(null);
//            exposure2.add(50l);
        }

        materialnfo1.materialId = 1l;
        materialnfo1.appId = 9l;
        materialnfo1.click=click1; //最近10分钟点击
        materialnfo1.exposure=exposure1; //最近10分钟曝光
        materialnfo1.setCount(0);
        materialnfo1.setHisClick(0);
        materialnfo1.setHisExposures(0);
        materialnfo1.setReword(0.0);

        Materialnfo materialnfo2 = new Materialnfo();

        //ArrayList<Long> clkList2 = new ArrayList<>();
        // clkList2.add(0,10l);
        //ArrayList<Long> expList2 = new ArrayList<>();

        materialnfo2.materialId = 2l;
        materialnfo2.appId = 9l;
        materialnfo2.click=click2; //最近10分钟点击
        materialnfo2.exposure=exposure2; //最近10分钟曝光
        materialnfo2.setCount(0);
        materialnfo2.setHisClick(0);
        materialnfo2.setHisExposures(0);
        materialnfo2.setReword(0.0);
        ArrayList<Materialnfo> activityList = new ArrayList<>();
        activityList.add(materialnfo1);
        activityList.add(materialnfo2);


        int cnt1 = 0,cnt2 = 0;
        //System.out.println("activityId\talpha\tm.beta\tm.reward\tm.hctr");

        for(int i = 0;i<10000;i++)
        {

            System.out.println("循环次数"+i);
            System.out.println("0LastClick= " +activityList.get(0).getHisClick());
            System.out.println("0getLastExposure= " +activityList.get(0).getHisExposures());
            System.out.println("0getReward= " +activityList.get(0).getReward());

            System.out.println("0getcounts= " +activityList.get(0).getCount());


            //处理过程中没有改变活动的 expList2 和 clkList2 ，所以每次点击和曝光列表的内容一样，但是改变了 LastClick，LastExposure，Reward，所以每次新循环，这几个指标都不一样了。

            Materialnfo materialnfo = banditActivity.selectActivity(activityList);
            //System.out.println("win_activity_id= " +activity.activityId);
            if(materialnfo.materialId == 2l)
            {

                activityList.set(1,materialnfo);  //不理解

                cnt2++;
//                System.out.println("activityList"+ activityList.get(0).getActivityId() +activityList.get(1).getActivityId());
            }
            else
            {
                activityList.set(0,materialnfo);
                cnt1++;
                //System.out.println("activityList"+ activityList.get(0).getActivityId() +activityList.get(1).getActivityId());
            }
            // System.out.println(m.materialId+"\t"+m.alpha+"\t"+m.beta+"\t"+m.reward/m.count+"\t"+m.lastClick+"\t"+m.lastExposure);
        }
        System.out.println("cnt1 = "+cnt1+" cnt2="+cnt2);
        //System.out.println("activityList"+ activityList.get(0).getActivityId() +activityList.get(1).getActivityId());


    }



}
/**
 0alphas= 11.00000000000001
 0betas= 9.999999999999979
 1alphas= 1.0999999999999999
 1betas= 19.899999999999988
 cnt1 = 9999 cnt2=1
 click1.add(20l);
 click2.add(null);



 1alphas= 5.000000000000633
 1betas= 15.999999999999357
 0alphas= 1.0999999999999999
 0betas= 19.899999999999988
 cnt1 = 292 cnt2=9708

 click1.add(null);
 click2.add(20l);
 **/
